from setuptools import setup

setup(name='torrs_hammers',
      version='0.1',
      description='useful tools',
      url='https://github.com/PyTorr/torrs_hammers/archive/refs/tags/v01.tar.gz',
      author='Torr',
      author_email='',
      license='MIT',
      packages=['torrs_hammers'],
      zip_safe=False)
